==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Váltás ablakra</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Váltás teljes képernyőre</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Visszaszámlálás</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A rögzítés nem indult el, nincs elég szabad lemezterület.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>A szabad lemezterület korlátja elérve.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Szabad lemezterület korlátja</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A rögzítés leállt, nincs elég szabad lemezterület.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nem található fájlkezelő.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Telepítsen egy fájlkezelőt.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Az asztali munkamenet egy Wayland munkamenet</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Az időhöz a Wayland nem támogatott. A képernyőrögzítés fekete képernyőt jelenít meg. Jelentkezzen ki, és indítson egy X11 asztali munkamenetet.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Forráskód</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Honlap</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Fordítások</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományozás</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland asztali munkamenet észlelhető</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Párbeszédablak</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vízszintes tükrözés</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Függőleges tükrözés</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Megfordítás</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szürke</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Fekete-fehér</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ablakkeret eltávolítása</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera beállításai</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Visszaállítás</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Visszaszámlálás</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videóméret:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Szabad lemezterület:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Rögzítés ideje:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Hang</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Képkockák</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Hangkodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Minőség</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne rögzítse az egérmutatót</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Óra</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Perc</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Az időzítő indítása</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Rögzítés leállítása ez után:</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Óra</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Perc</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Másodperc</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videó útvonala</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Szabad lemezterület korlátja</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Megjelenítés a tálcán</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Másodperc várakozás a rögzítés előtt</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Frissítések keresése</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Videó</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Elérhető</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nem érhető el</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Megfordítás</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szürke</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Jelentés küldése</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Utolsó rögzítés lejátszása</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimalizálás a rögzítés indulásakor</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Indítás minimalizálva</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vízszintes tükrözés</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Függőleges tükrözés</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Fekete-fehér</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ablakkeret eltávolítása</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományozás</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Összes beállítás visszaállítása a következő indításnál</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Fényképek szerzői joga és engedélye</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Képernyőrögzítés</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lejátszó</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Napló</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Fényképek szerzői joga és engedélye</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Előző képkocka</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Következő képkocka</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Menü áthelyezése</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Váltás ablakra</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Váltás teljes képernyőre</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Nem található fájlkezelő.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Telepítsen egy fájlkezelőt.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>A rögzítés nem indult el, nincs elég szabad lemezterület.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>A szabad lemezterület korlátja elérve.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Szabad lemezterület korlátja</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>A rögzítés leállt, nincs elég szabad lemezterület.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ablak</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Nem található fájlkezelő.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Telepítsen egy fájlkezelőt.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Forráskód</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Honlap</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Fordítások</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományozás</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Válasszon ki egy vagy több eszközt</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Nagyítás</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Párbeszédablak</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vízszintes tükrözés</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Függőleges tükrözés</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Megfordítás</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szürke</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Fekete-fehér</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ablakkeret eltávolítása</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera beállításai</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Terület</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Visszaállítás</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Nagyítás</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Visszaszámlálás</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videóméret:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Szabad lemezterület:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Rögzítés ideje:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Hang</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Képkockák</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formátum</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Hangkodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Minőség</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne rögzítse az egérmutatót</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Óra</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Perc</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Az időzítő indítása</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Rögzítés leállítása ez után:</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Óra</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Perc</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Másodperc</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videó útvonala</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Szabad lemezterület korlátja</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Megjelenítés a tálcán</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Másodperc várakozás a rögzítés előtt</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Frissítések keresése</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Videó</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Elérhető</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nem érhető el</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Megfordítás</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szürke</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Jelentés küldése</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Utolsó rögzítés lejátszása</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimalizálás a rögzítés indulásakor</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Indítás minimalizálva</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vízszintes tükrözés</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Függőleges tükrözés</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Fekete-fehér</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Ablakkeret eltávolítása</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Adományozás</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Összes beállítás visszaállítása a következő indításnál</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Fényképek szerzői joga és engedélye</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Képernyőrögzítés</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lejátszó</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Napló</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Fényképek szerzői joga és engedélye</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Előző képkocka</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Következő képkocka</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Menü áthelyezése</translation>
    </message>
</context>
</TS>
